@@ -180,6 +180,10 @@ vector_obj* gPSubTmpFiles;
 hash_obj* gMatchRestart;
     // matchで使う変数
 
+vector_obj* gStackTraceFName;
+vector_obj* gStackTraceLineNum;
+    // スタックの記録
+
 //////////////////////////////////////////////////////////
 // 内部関数
 //////////////////////////////////////////////////////////
@@ -2484,7 +2488,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
     gFileHandles = HASH_NEW(100);
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "0.9.6", 1);
+    setenv("SAPHIRE_VERSION", "0.9.7", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
@@ -2551,15 +2555,23 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
         strcpy(gTmpDir, "/tmp");
 
     gMatchRestart = HASH_NEW(100);
+    gStackTraceFName = VECTOR_NEW(30);
+    gStackTraceLineNum = VECTOR_NEW(30);
 
     tmpfile_all_sweep();
 }
 
 void saphire_final()
 {
+    int i;
+    for(i=0; i<vector_size(gStackTraceFName); i++) {
+        string_delete(vector_item(gStackTraceFName, i));
+    }
+    vector_delete(gStackTraceFName);
+    vector_delete(gStackTraceLineNum);
+
     hash_delete(gMatchRestart);
 
-    int i;
     int len = vector_size(gGlobalPipes);
     for(i=0; i<len; i++) {
         string_delete(vector_item(gGlobalPipes, i));
